@@ -4,13 +4,13 @@
 *
 ********************************************************************************
 *
-*  $Revision: 7 $
+*  $Revision: 11 $
 *  $Author: mhx $
-*  $Date: 2005/10/18 21:06:49 +0200 $
+*  $Date: 2008/10/12 20:53:51 +0200 $
 *
 ********************************************************************************
 *
-*  Version 3.x, Copyright (C) 2004-2005, Marcus Holland-Moritz.
+*  Version 3.x, Copyright (C) 2004-2008, Marcus Holland-Moritz.
 *  Version 2.x, Copyright (C) 2001, Paul Marquess.
 *  Version 1.x, Copyright (C) 1999, Kenneth Albanowski.
 *
@@ -29,6 +29,8 @@
 
 #define NEED_newCONSTSUB_GLOBAL
 #define NEED_PL_signals_GLOBAL
+#define NEED_PL_parser
+#define DPPP_PL_parser_NO_DUMMY
 #include "ppport.h"
 
 void call_newCONSTSUB_2(void)
@@ -40,3 +42,19 @@ U32 get_PL_signals_2(void)
 {
   return PL_signals;
 }
+
+int no_dummy_parser_vars(int check)
+{
+  if (check == 0 || PL_parser)
+  {
+    line_t volatile my_copline;
+    line_t volatile *my_p_copline;
+    my_copline = PL_copline;
+    my_p_copline = &PL_copline;
+    PL_copline = my_copline;
+    PL_copline = *my_p_copline;
+    return 1;
+  }
+
+  return 0;
+}
