@@ -4,13 +4,13 @@
 *
 ********************************************************************************
 *
-*  $Revision: 7 $
+*  $Revision: 11 $
 *  $Author: mhx $
-*  $Date: 2005/10/18 21:06:51 +0200 $
+*  $Date: 2008/10/12 20:53:51 +0200 $
 *
 ********************************************************************************
 *
-*  Version 3.x, Copyright (C) 2004-2005, Marcus Holland-Moritz.
+*  Version 3.x, Copyright (C) 2004-2008, Marcus Holland-Moritz.
 *  Version 2.x, Copyright (C) 2001, Paul Marquess.
 *  Version 1.x, Copyright (C) 1999, Kenneth Albanowski.
 *
@@ -22,6 +22,7 @@
 #include "EXTERN.h"
 #include "perl.h"
 
+#define NEED_PL_parser
 #define NO_XSLOCKS
 #include "XSUB.h"
 
@@ -63,3 +64,14 @@ U32 get_PL_signals_3(void)
 {
   return PL_signals;
 }
+
+int dummy_parser_warning(void)
+{
+  char * volatile my_bufptr;
+  char * volatile *my_p_bufptr;
+  my_bufptr = PL_bufptr;
+  my_p_bufptr = &PL_bufptr;
+  PL_bufptr = my_bufptr;
+  PL_bufptr = *my_p_bufptr;
+  return &PL_bufptr != NULL;
+}
